==> jc-1.4.0.tar.gz: java/util/Collections__24UnmodifiableListIterator.h <==
// final class java.util.Collections$UnmodifiableListIterator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6114b171567504f8 java_util_Collections__24UnmodifiableIterator
// @dep_class 34df57e86c659933 java_util_Collections__24UnmodifiableListIterator

// header file dependencies
// @dep_header java_util_Collections__24UnmodifiableIterator

#include "java/util/Collections__24UnmodifiableIterator.h"

#ifndef _JC_java_util_Collections__24UnmodifiableListIterator_H_
#define _JC_java_util_Collections__24UnmodifiableListIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_ListIterator$object;

// Typedefs
typedef struct _jc_java_util_Collections__24UnmodifiableListIterator$sub_refs	_jc_java_util_Collections__24UnmodifiableListIterator$sub_refs;
typedef struct _jc_java_util_Collections__24UnmodifiableListIterator$sub_nonrefs	_jc_java_util_Collections__24UnmodifiableListIterator$sub_nonrefs;
typedef struct _jc_java_util_Collections__24UnmodifiableListIterator$refs	_jc_java_util_Collections__24UnmodifiableListIterator$refs;
typedef struct _jc_java_util_Collections__24UnmodifiableListIterator$nonrefs	_jc_java_util_Collections__24UnmodifiableListIterator$nonrefs;
typedef struct _jc_java_util_Collections__24UnmodifiableListIterator$object	_jc_java_util_Collections__24UnmodifiableListIterator$object;

typedef const struct _jc_java_util_Collections__24UnmodifiableListIterator$vmethods	_jc_java_util_Collections__24UnmodifiableListIterator$vmethods;
typedef const struct _jc_java_util_Collections__24UnmodifiableListIterator$vtable	_jc_java_util_Collections__24UnmodifiableListIterator$vtable;
typedef const struct _jc_java_util_Collections__24UnmodifiableListIterator$vtype	_jc_java_util_Collections__24UnmodifiableListIterator$vtype;

// Constructors
extern void _jc_java_util_Collections__24UnmodifiableListIterator$method$_init$74fda43025818cbc(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableListIterator$object *, struct _jc_object *);

// Virtual methods
extern void _jc_java_util_Collections__24UnmodifiableListIterator$method$add$75d6bd5079bf5583(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableListIterator$object *, struct _jc_java_lang_Object$object *);
extern jboolean _jc_java_util_Collections__24UnmodifiableListIterator$method$hasPrevious$ba27b2748a9c0636(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableListIterator$object *);
extern jint _jc_java_util_Collections__24UnmodifiableListIterator$method$nextIndex$d07daaf318c84c0b(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableListIterator$object *);
extern struct _jc_java_lang_Object$object *_jc_java_util_Collections__24UnmodifiableListIterator$method$previous$ce61ba497a556ff1(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableListIterator$object *);
extern jint _jc_java_util_Collections__24UnmodifiableListIterator$method$previousIndex$a699da80acbceaa0(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableListIterator$object *);
extern void _jc_java_util_Collections__24UnmodifiableListIterator$method$set$5d552207ec221301(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableListIterator$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_Collections__24UnmodifiableListIterator$method_info$add$75d6bd5079bf5583;
extern _jc_method _jc_java_util_Collections__24UnmodifiableListIterator$method_info$hasPrevious$ba27b2748a9c0636;
extern _jc_method _jc_java_util_Collections__24UnmodifiableListIterator$method_info$nextIndex$d07daaf318c84c0b;
extern _jc_method _jc_java_util_Collections__24UnmodifiableListIterator$method_info$previous$ce61ba497a556ff1;
extern _jc_method _jc_java_util_Collections__24UnmodifiableListIterator$method_info$previousIndex$a699da80acbceaa0;
extern _jc_method _jc_java_util_Collections__24UnmodifiableListIterator$method_info$set$5d552207ec221301;

// Virtual methods structure
struct _jc_java_util_Collections__24UnmodifiableListIterator$vmethods {
	void	(*add$75d6bd5079bf5583)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableListIterator$object *, struct _jc_java_lang_Object$object *);
	jboolean	(*hasPrevious$ba27b2748a9c0636)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableListIterator$object *);
	jint	(*nextIndex$d07daaf318c84c0b)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableListIterator$object *);
	struct _jc_java_lang_Object$object	*(*previous$ce61ba497a556ff1)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableListIterator$object *);
	jint	(*previousIndex$a699da80acbceaa0)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableListIterator$object *);
	void	(*set$5d552207ec221301)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableListIterator$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_java_util_Collections__24UnmodifiableListIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_Collections__24UnmodifiableIterator$vmethods	java_util_Collections__24UnmodifiableIterator;
	_jc_java_util_Collections__24UnmodifiableListIterator$vmethods	java_util_Collections__24UnmodifiableListIterator;
};

// Vtype
struct _jc_java_util_Collections__24UnmodifiableListIterator$vtype {
	_jc_type			type;
	_jc_java_util_Collections__24UnmodifiableListIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Collections__24UnmodifiableListIterator$sub_refs {
	struct _jc_object	*li;
};

// Reference instance fields (object)
struct _jc_java_util_Collections__24UnmodifiableListIterator$refs {
    _jc_java_util_Collections__24UnmodifiableListIterator$sub_refs	java_util_Collections__24UnmodifiableListIterator;
    _jc_java_util_Collections__24UnmodifiableIterator$sub_refs	java_util_Collections__24UnmodifiableIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Collections__24UnmodifiableListIterator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_Collections__24UnmodifiableListIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_Collections__24UnmodifiableIterator$sub_nonrefs	java_util_Collections__24UnmodifiableIterator;
    _jc_java_util_Collections__24UnmodifiableListIterator$sub_nonrefs	java_util_Collections__24UnmodifiableListIterator;
};

// Object instance structure
struct _jc_java_util_Collections__24UnmodifiableListIterator$object {
	_jc_java_util_Collections__24UnmodifiableListIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Collections__24UnmodifiableListIterator$vtype	*vtype;
	_jc_java_util_Collections__24UnmodifiableListIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Collections__24UnmodifiableListIterator$vtype _jc_java_util_Collections__24UnmodifiableListIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Collections__24UnmodifiableListIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Collections__24UnmodifiableListIterator$class_object;

#endif	/* _JC_java_util_Collections__24UnmodifiableListIterator_H_ */

==> jc-1.4.6.tar.gz: java/util/Collections__24UnmodifiableListIterator.h <==
// final class java.util.Collections$UnmodifiableListIterator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6114b171567504f8 java_util_Collections__24UnmodifiableIterator
// @dep_class 34df57e86c659933 java_util_Collections__24UnmodifiableListIterator

// header file dependencies
// @dep_header java_util_Collections__24UnmodifiableIterator

#include "java/util/Collections__24UnmodifiableIterator.h"

#ifndef _JC_java_util_Collections__24UnmodifiableListIterator_H_
#define _JC_java_util_Collections__24UnmodifiableListIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_ListIterator$object;

// Typedefs
typedef struct _jc_java_util_Collections__24UnmodifiableListIterator$sub_refs	_jc_java_util_Collections__24UnmodifiableListIterator$sub_refs;
typedef struct _jc_java_util_Collections__24UnmodifiableListIterator$sub_nonrefs	_jc_java_util_Collections__24UnmodifiableListIterator$sub_nonrefs;
typedef struct _jc_java_util_Collections__24UnmodifiableListIterator$refs	_jc_java_util_Collections__24UnmodifiableListIterator$refs;
typedef struct _jc_java_util_Collections__24UnmodifiableListIterator$nonrefs	_jc_java_util_Collections__24UnmodifiableListIterator$nonrefs;
typedef struct _jc_java_util_Collections__24UnmodifiableListIterator$object	_jc_java_util_Collections__24UnmodifiableListIterator$object;

typedef const struct _jc_java_util_Collections__24UnmodifiableListIterator$vmethods	_jc_java_util_Collections__24UnmodifiableListIterator$vmethods;
typedef const struct _jc_java_util_Collections__24UnmodifiableListIterator$vtable	_jc_java_util_Collections__24UnmodifiableListIterator$vtable;
typedef const struct _jc_java_util_Collections__24UnmodifiableListIterator$vtype	_jc_java_util_Collections__24UnmodifiableListIterator$vtype;

// Constructors
extern void _jc_java_util_Collections__24UnmodifiableListIterator$method$_init$74fda43025818cbc(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableListIterator$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_util_Collections__24UnmodifiableListIterator$method$add$75d6bd5079bf5583(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableListIterator$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_util_Collections__24UnmodifiableListIterator$method$hasPrevious$ba27b2748a9c0636(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableListIterator$object *) _JC_JCNI_ATTR;
extern jint _jc_java_util_Collections__24UnmodifiableListIterator$method$nextIndex$d07daaf318c84c0b(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableListIterator$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_util_Collections__24UnmodifiableListIterator$method$previous$ce61ba497a556ff1(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableListIterator$object *) _JC_JCNI_ATTR;
extern jint _jc_java_util_Collections__24UnmodifiableListIterator$method$previousIndex$a699da80acbceaa0(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableListIterator$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_Collections__24UnmodifiableListIterator$method$set$5d552207ec221301(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableListIterator$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_Collections__24UnmodifiableListIterator$method_info$add$75d6bd5079bf5583;
extern _jc_method _jc_java_util_Collections__24UnmodifiableListIterator$method_info$hasPrevious$ba27b2748a9c0636;
extern _jc_method _jc_java_util_Collections__24UnmodifiableListIterator$method_info$nextIndex$d07daaf318c84c0b;
extern _jc_method _jc_java_util_Collections__24UnmodifiableListIterator$method_info$previous$ce61ba497a556ff1;
extern _jc_method _jc_java_util_Collections__24UnmodifiableListIterator$method_info$previousIndex$a699da80acbceaa0;
extern _jc_method _jc_java_util_Collections__24UnmodifiableListIterator$method_info$set$5d552207ec221301;

// Virtual methods structure
struct _jc_java_util_Collections__24UnmodifiableListIterator$vmethods {
	void	(*add$75d6bd5079bf5583)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableListIterator$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jboolean	(*hasPrevious$ba27b2748a9c0636)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableListIterator$object *) _JC_JCNI_ATTR;
	jint	(*nextIndex$d07daaf318c84c0b)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableListIterator$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*previous$ce61ba497a556ff1)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableListIterator$object *) _JC_JCNI_ATTR;
	jint	(*previousIndex$a699da80acbceaa0)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableListIterator$object *) _JC_JCNI_ATTR;
	void	(*set$5d552207ec221301)(_jc_env *, struct _jc_java_util_Collections__24UnmodifiableListIterator$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_Collections__24UnmodifiableListIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_Collections__24UnmodifiableIterator$vmethods	java_util_Collections__24UnmodifiableIterator;
	_jc_java_util_Collections__24UnmodifiableListIterator$vmethods	java_util_Collections__24UnmodifiableListIterator;
};

// Vtype
struct _jc_java_util_Collections__24UnmodifiableListIterator$vtype {
	_jc_type			type;
	_jc_java_util_Collections__24UnmodifiableListIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Collections__24UnmodifiableListIterator$sub_refs {
	struct _jc_object	*li;
};

// Reference instance fields (object)
struct _jc_java_util_Collections__24UnmodifiableListIterator$refs {
    _jc_java_util_Collections__24UnmodifiableListIterator$sub_refs	java_util_Collections__24UnmodifiableListIterator;
    _jc_java_util_Collections__24UnmodifiableIterator$sub_refs	java_util_Collections__24UnmodifiableIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Collections__24UnmodifiableListIterator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_Collections__24UnmodifiableListIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_Collections__24UnmodifiableIterator$sub_nonrefs	java_util_Collections__24UnmodifiableIterator;
    _jc_java_util_Collections__24UnmodifiableListIterator$sub_nonrefs	java_util_Collections__24UnmodifiableListIterator;
};

// Object instance structure
struct _jc_java_util_Collections__24UnmodifiableListIterator$object {
	_jc_java_util_Collections__24UnmodifiableListIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Collections__24UnmodifiableListIterator$vtype	*vtype;
	_jc_java_util_Collections__24UnmodifiableListIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Collections__24UnmodifiableListIterator$vtype _jc_java_util_Collections__24UnmodifiableListIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Collections__24UnmodifiableListIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Collections__24UnmodifiableListIterator$class_object;

#endif	/* _JC_java_util_Collections__24UnmodifiableListIterator_H_ */
